==> wetterdienst-0.99.0.tar.gz: wetterdienst-0.99.0/docs/data/provider/ea/hydrology/15_minutes.md <==
# 15_minutes

## metadata

| property      | value                                                                      |
|---------------|----------------------------------------------------------------------------|
| name          | 15_minutes                                                                 |
| original name | 15_minutes                                                                 |
| description   | no specific dataset is provided but parameters can be queried individually |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)            |

## datasets

### data

#### metadata

| property      | value                                                                              |
|---------------|------------------------------------------------------------------------------------|
| name          | data                                                                               |
| original name | data                                                                               |
| description   | Historical 15 minute station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                    |

#### parameters

| name              | original name     | description                       | unit | original unit | constraints |
|-------------------|-------------------|-----------------------------------|------|---------------|-------------|
| flow              | water flow        | 15 minutes mean flow              | m³/s | m³/s          | >=0         |
| groundwater_level | groundwater level | 15 minutes mean groundwater level | m    | m             | >=0         |

==> wetterdienst-0.103.0.tar.gz: wetterdienst-0.103.0/docs/data/provider/ea/hydrology/15_minutes.md <==
# 15_minutes

## metadata

| property      | value                                                                      |
|---------------|----------------------------------------------------------------------------|
| name          | 15_minutes                                                                 |
| original name | 15_minutes                                                                 |
| description   | no specific dataset is provided but parameters can be queried individually |
| url           | [here](https://environment.data.gov.uk/hydrology/doc/reference)            |

## datasets

### data

#### metadata

| property      | value                                                                              |
|---------------|------------------------------------------------------------------------------------|
| name          | data                                                                               |
| original name | data                                                                               |
| description   | Historical 15 minute station observations of flow and groundwater level for the UK |
| access        | [here](https://environment.data.gov.uk/hydrology/doc/reference)                    |

#### parameters

| name              | original name     | description                       | unit type       | unit          | constraints |
|-------------------|-------------------|-----------------------------------|-----------------|---------------|-------------|
| flow              | water flow        | 15 minutes mean flow              | volume_per_time | m³/s          | >=0         |
| groundwater_level | groundwater level | 15 minutes mean groundwater level | length_medium   | m             | >=0         |
